@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Django page CMS ``managers``."""
 from basic_cms import settings
-from basic_cms.utils import normalize_url, filter_link
+from basic_cms.utils import normalize_url
 from basic_cms.http import get_slug
 
 from django.db import models, connection
@@ -374,13 +374,12 @@ class ContentManager(models.Manager):
             cache.set(key, content_dict)
 
         if language in content_dict and content_dict[language]:
-            return filter_link(content_dict[language], page, language, ctype)
+            return content_dict[language]
 
         if language_fallback:
             for lang in settings.PAGE_LANGUAGES:
                 if lang[0] in content_dict and content_dict[lang[0]]:
-                    return filter_link(content_dict[lang[0]], page, lang[0],
-                        ctype)
+                    return content_dict[lang[0]]
         return ''
 
     def get_content_slug_by_slug(self, slug):
